@@ -4,11 +4,14 @@ pub mod prelude;
 pub use notan::*;
 pub use notan_app as app;
 pub use notan_graphics as graphics;
+pub use notan_input as input;
 pub use notan_macro::*;
 pub use notan_math as math;
 pub use notan_utils as utils;
 
-#[cfg(feature = "default_backend")]
+pub use notan_core::events::Event;
+
+#[cfg(feature = "backend")]
 pub use notan_backend as backend;
 
 #[cfg(feature = "audio")]
