@@ -1,10 +1,11 @@
 use crate::app::{AppBuilder, BackendSystem, SetupHandler};
 
-#[cfg(not(feature = "default_backend"))]
+#[cfg(not(feature = "backend"))]
 use crate::app::empty::EmptyBackend as DefaultBackend;
 
-#[cfg(feature = "default_backend")]
+#[cfg(feature = "backend")]
 use notan_backend::DefaultBackend;
+use notan_log::LogConfig;
 
 /// Initialize the app with the default backend and with an empty state
 pub fn init() -> AppBuilder<(), DefaultBackend> {
@@ -27,14 +28,12 @@ where
     B: BackendSystem + 'static,
     H: SetupHandler<S, Params>,
 {
-    #[cfg(feature = "log_enabled")]
-    {
-        #[cfg(debug_assertions)]
-        crate::log::init();
+    let mut builder = AppBuilder::new(setup, backend);
 
-        #[cfg(not(debug_assertions))]
-        crate::log::init_with_level(crate::log::Level::Warn);
+    #[cfg(feature = "log")]
+    {
+        builder = builder.add_config(LogConfig::default());
     }
 
-    AppBuilder::new(setup, backend)
+    builder
 }
