@@ -1,6 +1,8 @@
 pub use crate::app::prelude::*;
 pub use crate::graphics::prelude::*;
+pub use crate::input::prelude::*;
 pub use crate::math::prelude::*;
+pub use crate::Event;
 pub use notan_macro::{notan_main, AppState};
 
 #[cfg(feature = "audio")]
